@@ -1,4 +1,4 @@
-# ZestyParser 0.3.0 -- Parses in Python zestily
+# ZestyParser 0.4.0 -- Parses in Python zestily
 # Copyright (C) 2006 Adam Atlas
 # 
 # This program is free software; you can redistribute it and/or
@@ -15,4 +15,4 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-from Parser import ZestyParser, NotMatched, ParseError, EOF, ReturnRaw, ReturnDirect, Token, CompositeToken, TokenSequence
+from Parser import *
\ No newline at end of file
